#!/bin/sh -e

# Move to configuration directory
cd /user/spf2/etc

# Create configuration and version files
ln -fs /user/spf2/etc/config.json /tmp/packet_forwarder.conf
echo spf2 5.1.0-klk3 +hal_libloragw2_5.1.0-klk5 > /tmp/packet_forwarder_version.txt

# Open firewall ports
iptables_accept() {
	local RULE="OUTPUT -t filter -p udp --dport ${1} -j ACCEPT"
	iptables -C ${RULE} 2> /dev/null || iptables -I ${RULE}
	local RULE="INPUT -t filter -p udp --sport ${1} -j ACCEPT"
	iptables -C ${RULE} 2> /dev/null || iptables -I ${RULE}
}

iptables_accept "$(/user/spf2/bin/configure_spf2 "gateway_conf.serv_port_up")"
iptables_accept "$(/user/spf2/bin/configure_spf2 "gateway_conf.serv_port_down")"

(
	# Lock on pid file
	exec 8> /var/run/packet_forwarder.pid
	flock -n -x 8
	trap "rm -f /var/run/packet_forwarder.pid" EXIT

	# Start packet forwarder
	/user/spf2/bin/spf2 -g /dev/nmea1 -y 2>&1 | logger -p local1.notice -t spf2 &
	trap "killall -q spf2" INT QUIT TERM

	# Update pid and wait for it
	pidof spf2 >&8
	wait
) &
